emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/topspace 334fecd4c4 068/181: Update description in tops


From: ELPA Syncer
Subject: [elpa] externals/topspace 334fecd4c4 068/181: Update description in topspace.el and readme.md
Date: Tue, 23 Aug 2022 12:58:34 -0400 (EDT)

branch: externals/topspace
commit 334fecd4c40c6ac37362507664690619e2b07ab6
Author: Trevor Pogue <poguete@mcmaster.ca>
Commit: Trevor Pogue <poguete@mcmaster.ca>

    Update description in topspace.el and readme.md
---
 README.md   |  6 +++---
 topspace.el | 32 ++++++++++++++++++++++----------
 2 files changed, 25 insertions(+), 13 deletions(-)

diff --git a/README.md b/README.md
index 86f819c016..2aeb1fa7ba 100644
--- a/README.md
+++ b/README.md
@@ -1,5 +1,5 @@
 <h1 align="center"> TopSpace </h1>
-<p align="center">Scroll down and recenter top lines in Emacs / get upper 
margins/padding.</p>
+<p align="center">Scroll down & recenter top lines in Emacs / get upper 
margins/padding.</p>
 
 <!-- padding cursor -->
 
@@ -12,7 +12,7 @@
 <p align="center"><img 
src="https://user-images.githubusercontent.com/12535207/155176914-87390537-10f0-4ee5-9b37-cd798f07df27.gif";
 /></a></p>
 
 TopSpace is an Emacs minor mode that allows you to scroll down and recenter 
top lines
-by automatically drawing upper margins/padding above the top line
+by automatically drawing an upper margin/padding above the top line
 as you scroll down or recenter top text.
 
 TopSpace is:
@@ -88,7 +88,7 @@ scrolling.  This includes all scrolling commands/functions 
available
 in Emacs as far as the author is aware. This is achieved by using
 `advice-add` with the `scroll-up`, `scroll-down`, and `recenter`
 commands so that custom topspace functions are called before or after
-each time any of these commands are called (interactively or
+each time any of these other commands are called (interactively or
 otherwise).
 
 
diff --git a/topspace.el b/topspace.el
index e38b912a41..a4d36b10d2 100644
--- a/topspace.el
+++ b/topspace.el
@@ -24,7 +24,7 @@
 
 ;;; Commentary:
 ;; TopSpace allows you to scroll down and recenter top lines
-;; by automatically drawing upper margins/padding above the top line
+;; by automatically drawing an upper margin/padding above the top line
 ;; as you scroll down or recenter top text.
 
 ;; TopSpace is:
@@ -51,7 +51,7 @@
 ;; in Emacs as far as the author is aware. This is achieved by using
 ;; `advice-add' with the `scroll-up', `scroll-down', and `recenter'
 ;; commands so that custom topspace functions are called before or after
 ;; each time any of these commands are called (interactively or
 ;; otherwise).
 
 ;; See the readme at https://github.com/trevorpogue/topspace for more
@@ -97,7 +97,7 @@ space should be reduced in size or not")
 ;;; Customization
 
 (defgroup topspace nil
-  "Scroll above the top line to vertically center top text."
+  "Scroll down & recenter top lines / get upper margins/padding."
   :group 'scrolling
   :group 'convenience
   :link '(emacs-library-link :tag "Source Lisp File" "topspace.el")
@@ -435,7 +435,13 @@ Topspace will not be enabled for:
 
 ;;;###autoload
 (define-minor-mode topspace-mode
-  "Scroll down and recenter top lines.
+  "Scroll down & recenter top lines / get upper margins/padding.
+
+TopSpace allows you to scroll down and recenter top lines
+by automatically drawing an upper margin/padding above the top line
+as you scroll down or recenter top text.
+
+TopSpace is:
 
 - Easier on the eyes: Recenter or scroll down top text to a more
   comfortable eye level for reading, especially when in full-screen
@@ -447,17 +453,23 @@ Topspace will not be enabled for:
   seamlessly with `centered-cursor-mode' to keep the cursor
   centered all the way to the top line.
 
-How it works:
-A top margin is created above the top text line as you scroll down
-top text.  The \"margin\" is created by drawing an overlay before
-window-start containing newline characters. As you scroll above the
+How it works under the hood:
+The \"upper margin\" is created by drawing an overlay before
+window-start containing newline characters.  As you scroll above the
 top line, more newline characters are added or removed accordingly.
 
 No new keybindings are required as topspace automatically works for
 any commands or subsequent function calls which use `scroll-up',
 `scroll-down', or `recenter' as the underlying primitives for
-scrolling. This includes all scrolling commands/functions available
-in Emacs as far as the author is aware.
+scrolling.  This includes all scrolling commands/functions available
+in Emacs as far as the author is aware. This is achieved by using
+`advice-add' with the `scroll-up', `scroll-down', and `recenter'
+commands so that custom topspace functions are called before or after
+each time any of these other commands are called (interactively or
+otherwise).
+
+See the readme at https://github.com/trevorpogue/topspace for more
+information.
 
 Enabling/disabling:
 When called interactively, toggle variable `topspace-mode'.
@@ -51,7 +51,7 @@
 ;; `advice-add' with the `scroll-up', `scroll-down', and `recenter'
 ;; commands so that custom topspace functions are called before or after
-;; each time any of these commands are called (interactively or
+;; each time any of these other commands are called (interactively or
 ;; otherwise).
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]